==> nextcloud-24.0.10.tgz: nextcloud/apps/user_status/l10n/uk.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Останні статуси",
    "In a meeting" : "На зустрічі",
    "Commuting" : "Поїздка на роботу",
    "Out sick" : "Захворіла",
    "Vacationing" : "Відпустка",
    "Working remotely" : "Робота віддалена",
    "In a call" : "У дзвінку",
    "User status" : "Статус користувача",
    "View profile" : "Перегляд профілю",
    "Clear status after" : "Очистити статус після",
    "What is your status?" : "Який твій статус?",
    "Set status" : "Встановити статус",
    "Online status" : "Статус онлайну",
    "Status message" : "Повідомлення про статус",
    "Clear status message" : "Очистити повідомлення про стан",
    "Set status message" : "Встановити повідомлення про стан",
    "There was an error saving the status" : "Під час збереження статусу сталася помилка",
    "There was an error clearing the status" : "Під час очищення статусу сталася помилка",
    "No recent status changes" : "Останніх змін статусу немає",
    "Away" : "Піти",
    "Do not disturb" : "Не турбувати",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Не очистувати",
    "Today" : "Сьогодні",
    "This week" : "Цього тижня",
    "Online" : "Онлайн",
    "Invisible" : "Невидима",
    "Offline" : "Офлайн",
    "There was an error saving the new status" : "Під час збереження нового статусу сталася помилка",
    "30 minutes" : "30 хвилин",
    "1 hour" : "1 година",
    "4 hours" : "4 години",
    "Mute all notifications" : "Вимкнути всі сповіщення",
    "Appear offline" : "З'являтися офлайн",
    "Clear status message after" : "Очистити повідомлення про стан після"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/user_status/l10n/uk.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Останні статуси",
    "No recent status changes" : "Останніх змін статусу немає",
    "In a meeting" : "На зустрічі",
    "Commuting" : "Поїздка на роботу",
    "Out sick" : "Захворіла",
    "Vacationing" : "Відпустка",
    "Working remotely" : "Робота віддалена",
    "In a call" : "У дзвінку",
    "User status" : "Статус користувача",
    "View profile" : "Перегляд профілю",
    "Clear status after" : "Очистити статус після",
    "What is your status?" : "Який твій статус?",
    "Previously set" : "Раніше встановлений",
    "Reset status" : "Скинути статус",
    "Set status" : "Встановити статус",
    "Online status" : "Статус онлайну",
    "Status message" : "Повідомлення про статус",
    "Your status was set automatically" : "Ваш статус встановлено автоматично",
    "Clear status message" : "Очистити повідомлення про стан",
    "Set status message" : "Встановити повідомлення про стан",
    "Reset status to \"{icon} {message}\"" : "Скинути статус на \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Скинути статус на \"{message}\"",
    "Reset status to \"{icon}\"" : "Скинути статус на \"{icon}\"",
    "There was an error saving the status" : "Під час збереження статусу сталася помилка",
    "There was an error clearing the status" : "Під час очищення статусу сталася помилка",
    "There was an error reverting the status" : "Виникла помилка при скиданні статусу",
    "Don't clear" : "Не очистувати",
    "Today" : "Сьогодні",
    "This week" : "Цього тижня",
    "Online" : "Онлайн",
    "Away" : "Піти",
    "Do not disturb" : "Не турбувати",
    "Invisible" : "Невидима",
    "Offline" : "Офлайн",
    "There was an error saving the new status" : "Під час збереження нового статусу сталася помилка",
    "30 minutes" : "30 хвилин",
    "1 hour" : "1 година",
    "4 hours" : "4 години",
    "Mute all notifications" : "Вимкнути всі сповіщення",
    "Appear offline" : "З'являтися офлайн",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
